'''
avlib 0.4

(c) 2003 Jan ONDREJ (SAL) <ondrejj@salstar.sk>

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.
    
'''

import os,sys,re,string,time,tempfile,traceback

BUFSIZE=10240
ROOT_PATH=''
MASTER_PID=os.getpid()
logfd=sys.stderr
INT_DEBUG_LEVEL=2

class ScannerError(Exception):
      """Any Error Of Any Scanner"""

def set_debug_level(level):
    global INT_DEBUG_LEVEL
    INT_DEBUG_LEVEL=level

def debug(level,*s):
    if INT_DEBUG_LEVEL>=level:
      o=''
      for i in s:
        if type(i)==type([]):
          for x in i:
            o=o+str(x)
        else:
          o=o+str(i)
      p=os.getpid()
      if p==MASTER_PID:
        logfd.write(o+'\n')
      else:
        logfd.write("%6s: %s\n" % (p,o))
    
def debug_traceback(level,arg):
    debug(level,arg+str(traceback.format_exception(sys.exc_type,
                      sys.exc_value, sys.exc_traceback)))

def traceback_value_str():
    return string.join(traceback.format_exception_only(
                           sys.exc_type, sys.exc_value),', ')

class popen:
  exitstatus=-1
  def __init__(self, cmd, wd=''):
      self.pcr,self.pcw = os.pipe()
      self.cpr,self.cpw = os.pipe()
      self.pid = os.fork()
      if self.pid == 0: # child
        os.close(self.pcw)
        os.close(self.cpr)
        os.dup2(self.pcr,0)
        os.dup2(self.cpw,1)
        os.dup2(self.cpw,2)
        try:
          if wd:
            os.chdir(wd)
          os.execvp(cmd[0],cmd)
        except os.error,(ec,es):
          sys.exit(1)
      os.close(self.pcr)
      os.close(self.cpw)
      self.tocmd=os.fdopen(self.pcw, 'w')
      self.fromcmd=os.fdopen(self.cpr, 'r')
  def wait(self):
      pid,self.exitstatus=os.waitpid(self.pid,0)
      return self.exitstatus
  def readlines(self):
      return self.fromcmd.readlines()
  def write(self,s):
      return self.tocmd.write(s)
  def close(self,rw=3):
      if rw&1:
        self.tocmd.flush()
        os.close(self.pcw)
      if rw&2:
        os.close(self.cpr)

def rlistdir(rootpath,path=''):
    files=[]
    try:
      listdir=os.listdir(os.path.join(rootpath,path))
    except:
      return []
    for d in os.listdir(os.path.join(rootpath,path)):
      if os.lstat(os.path.join(rootpath,path,d))[0] & 0x4000: # is_dir
        files=files+rlistdir(rootpath,os.path.join(path,d))
      else:
        files.append(os.path.join(path,d))
    return files

def fromhdr():
    return "From local@local.local"+\
      time.strftime("  %c\r\n",time.localtime(time.time()))

def smktemp(s):
    global ROOT_PATH
    return ROOT_PATH+tempfile.mktemp(s)

def creatembox(file,data,addheader=0):
    try:
      fd=os.open(file,os.O_WRONLY|os.O_CREAT|os.O_EXCL, 0600)
      f=os.fdopen(fd,'w',BUFSIZE)
      if addheader:
        f.write("From local@local"+\
          time.strftime("  %c\n",time.localtime(time.time())))
      f.write(data)
      f.close()
    except os.error,(ec,es):
      debug(0,'creatembox: open error: ',es,[[file]])
      raise
    except IOError,(ec,es):
      debug(0,'creatembox: ioerror: ',es,[[file]])
      raise

def tempcleanup(file,s=''):
    try:
      os.unlink(file)
    except OSError,(er,es):
      debug(0,s+": OSError: ",es,file)

def scan_over(scanner,streams):
    detected,virlist='',[]
    for stream in streams:
      d,v=clamscanf(stream,self.arg)
      if not detected:
        detected=d
      virlist=virlist+v
    return detected,virlist

class ascanner:
  name='AScanner'
  is_spamscan=0
  is_multistream=0
  def __init__(self,arg):
      self.arg=arg
  def scanstream(self,stream):
      raise 'ascanner','Not implemented'
  def scanfile(self,files,dirname=''):
      raise 'ascanner','Not implemented'
