#!/bin/sh

if [ "$1" ]; then
  export ROOTPATH="$1"
else
  export ROOTPATH=root
fi

addfile() {
  cp -f $1 $ROOTPATH/$1
}

addbin() {
  n=0
  for file in "$@"; do
    if [ -f $file ]; then
      n=`expr $n + 1`
      cp -f $file $ROOTPATH/$file
      if ldd $file > /dev/null; then
        for i in `ldd $file | awk '{print $3}' | sed 's/^\/lib\/tls/\/lib/g'`; do
          addbin $i
        done
      fi
    fi
  done
  if [ "$n" = "0" ]; then
    echo "Commands $@ are missing!"
  fi
}

adduser() {
  grep ^$1 /etc/passwd >> $ROOTPATH/etc/passwd
}

addgroup() {
  grep ^$1 /etc/group | sed -e 's/:[^:]*$/:/g' >> $ROOTPATH/etc/group
}

mkdir -p $ROOTPATH/{dev,etc,bin,lib,tmp/quarantine,usr/bin,usr/lib,usr/share}

cat > $ROOTPATH/etc/nsswitch.conf <<EOF
passwd:     files
shadow:     files
group:      files

hosts:      files,dns

ethers:     files
netmasks:   files
networks:   files
protocols:  files
rpc:        files
services:   files
EOF

cat > $ROOTPATH/etc/hosts <<EOF
127.0.0.1	localhost.localdomain localhost
EOF

rm -f $ROOTPATH/etc/passwd
adduser root
adduser clamav
adduser vscan

rm -f $ROOTPATH/etc/group
addgroup root
addgroup clamav
addgroup vscan

echo "/usr/lib" > $ROOTPATH/etc/ld.so.conf
touch $ROOTPATH/dev/null
touch $ROOTPATH/dev/zero
dd if=/dev/urandom of=$ROOTPATH/dev/urandom bs=1024 count=10 2> /dev/null

addbin /bin/gzip /usr/bin/gzip
addbin /bin/bzip2 /usr/bin/bzip2
addbin /bin/tar /usr/bin/tar
addbin /usr/bin/compress /bin/compress
for i in unzip lha arc; do
  addbin /usr/bin/$i
done
for i in rar arj zoo ace; do
  addbin /usr/bin/un$i /usr/bin/$i
done

addbin /usr/bin/clamscan
addfile /etc/clamav.conf
mkdir -p $ROOTPATH/usr/share/clamav
addfile /usr/share/clamav/viruses.db
addfile /usr/share/clamav/viruses.db2

ldconfig -r $ROOTPATH

chown -R root.root $ROOTPATH
chown -R vscan.vscan $ROOTPATH/tmp
chgrp -R vscan $ROOTPATH
chmod -R g+r,o-rwx $ROOTPATH
chmod g+x `find $ROOTPATH -type d`
